N, W Slepian sequence
family member, with the additional property that the smoother captures/passes constants
without distortion. Simply re-arranges object. Not intended to be used
directly by user.
"Predict.matrix"(object,data)s(..., bs = 'slp', ..., xt = list(...)),
and for this type, requiring an additional xt = list() object containing parameters.
For examples, see below. object[['term']]. Typically just a single time index array.object, which contains the
X basis vectors in a format that can be used by predict or
plot.
mgcv passes objects around without including the actual basis
vectors. For example, if using basis cr, the parameters are included in
object, and then the bases re-computed as needed. As the slp basis is significantly more computational in nature, the
basis vectors are saved as part of the object. While mgcv deletes
the main set of time-aligned vectors, this routine restores such vectors
so that predict and plot work correctly.
smooth.construct,
Predict.matrix